[seam-commits] Seam SVN: r7907 - trunk/src/remoting/org/jboss/seam/remoting/gwt.

seam-commits at lists.jboss.org seam-commits at lists.jboss.org
Fri Apr 11 23:31:14 EDT 2008


Author: shane.bryzak at jboss.com
Date: 2008-04-11 23:31:14 -0400 (Fri, 11 Apr 2008)
New Revision: 7907

Modified:
   trunk/src/remoting/org/jboss/seam/remoting/gwt/GWTService.java
Log:
JBSEAM-2880

Modified: trunk/src/remoting/org/jboss/seam/remoting/gwt/GWTService.java
===================================================================
--- trunk/src/remoting/org/jboss/seam/remoting/gwt/GWTService.java	2008-04-11 09:22:28 UTC (rev 7906)
+++ trunk/src/remoting/org/jboss/seam/remoting/gwt/GWTService.java	2008-04-12 03:31:14 UTC (rev 7907)
@@ -427,8 +427,8 @@
       // Content-Type must be specified.
       if (contentType != null)
       {
-         // The type must be plain text.
-         if (contentType.startsWith("text/plain"))
+         // The type must be plain text or text/x-gwt-rpc
+         if (contentType.startsWith("text/plain") || contentType.startsWith("text/x-gwt-rpc"))
          {
             // And it must be UTF-8 encoded (or unspecified, in which case we
             // assume that it's either UTF-8 or ASCII).
@@ -444,7 +444,7 @@
       if (!contentTypeIsOkay)
       {
          throw new ServletException(
-               "Content-Type must be 'text/plain' with 'charset=utf-8' (or unspecified charset)");
+               "Content-Type must be 'text/plain' or 'text/x-gwt-rpc' with 'charset=utf-8' (or unspecified charset)");
       }
       InputStream in = request.getInputStream();
       try




More information about the seam-commits mailing list